# -*- encoding:utf-8 -*-
"""Autogenerated file, do not edit. Submit translations on Transifex."""

MESSAGES = {
    "%d min remaining to read": "",
    "(active)": "(mātātoa)",
    "Also available in:": "",
    "Archive": "Pūranga",
    "Atom feed": "",
    "Authors": "Kaituhi",
    "Categories": "Kāwai",
    "Comments": "Kōrerohia",
    "LANGUAGE": " Māori",
    "Languages:": "Reo",
    "More posts about %s": "",
    "Newer posts": "",
    "Next post": "",
    "Next": "Panuku",
    "No posts found.": "",
    "Nothing found.": "Kīhai i kitea",
    "Older posts": "",
    "Original site": "",
    "Posted:": "",
    "Posts about %s": "",
    "Posts by %s": "",
    "Posts for year %s": "",
    "Posts for {month_day_year}": "",
    "Posts for {month_year}": "",
    "Previous post": "",
    "Previous": "Whakamuri",
    "Publication date": "",
    "RSS feed": "Whāngai RSS",
    "Read in English": "",
    "Read more": "",
    "Skip to main content": "",
    "Source": "Matapuna",
    "Subcategories:": "",
    "Tags and Categories": "Tūtohu me nga kāwai",
    "Tags": "Tūtohu",
    "Toggle navigation": "",
    "Uncategorized": "",
    "Up": "Ki runga",
    "Updates": "Whakahou",
    "Write your page here.": "",
    "Write your post here.": "",
    "old posts, page %d": "",
    "page %d": "whārangi %d",
    "updated": "whakahoutia",
}



"""
Helper utilities and classes for Nikola tests.

Alongside a contextmanager to switch directories this module contains
a Site substitute for rendering tests.
"""

import os
from contextlib import contextmanager

from yapsy.PluginManager import PluginManager

import nikola.utils
import nikola.shortcodes
from nikola.plugin_categories import (
    Command,
    Task,
    LateTask,
    TemplateSystem,
    PageCompiler,
    TaskMultiplier,
    CompilerExtension,
    MarkdownExtension,
    RestExtension,
)

__all__ = ["cd", "FakeSite"]


@contextmanager
def cd(path):
    old_dir = os.getcwd()
    os.chdir(path)
    yield
    os.chdir(old_dir)


class FakeSite:
    def __init__(self):
        self.template_system = self
        self.invariant = False
        self.debug = True
        self.config = {
            "DISABLED_PLUGINS": [],
            "EXTRA_PLUGINS": [],
            "DEFAULT_LANG": "en",
            "MARKDOWN_EXTENSIONS": [
                "markdown.extensions.fenced_code",
                "markdown.extensions.codehilite",
            ],
            "TRANSLATIONS_PATTERN": "{path}.{lang}.{ext}",
            "LISTINGS_FOLDERS": {"listings": "listings"},
            "TRANSLATIONS": {"en": ""},
        }
        self.EXTRA_PLUGINS = self.config["EXTRA_PLUGINS"]
        self.plugin_manager = PluginManager(
            categories_filter={
                "Command": Command,
                "Task": Task,
                "LateTask": LateTask,
                "TemplateSystem": TemplateSystem,
                "PageCompiler": PageCompiler,
                "TaskMultiplier": TaskMultiplier,
                "CompilerExtension": CompilerExtension,
                "MarkdownExtension": MarkdownExtension,
                "RestExtension": RestExtension,
            }
        )
        self.shortcode_registry = {}
        self.plugin_manager.setPluginInfoExtension("plugin")
        places = [os.path.join(os.path.dirname(nikola.utils.__file__), "plugins")]
        self.plugin_manager.setPluginPlaces(places)
        self.plugin_manager.collectPlugins()
        self.compiler_extensions = self._activate_plugins_of_category(
            "CompilerExtension"
        )

        self.timeline = [FakePost(title="Fake post", slug="fake-post")]
        self.rst_transforms = []
        self.post_per_input_file = {}
        # This is to make plugin initialization happy
        self.template_system = self
        self.name = "mako"

    def _activate_plugins_of_category(self, category):
        """Activate all the plugins of a given category and return them."""
        # this code duplicated in nikola/nikola.py
        plugins = []
        for plugin_info in self.plugin_manager.getPluginsOfCategory(category):
            if plugin_info.name in self.config.get("DISABLED_PLUGINS"):
                self.plugin_manager.removePluginFromCategory(plugin_info, category)
            else:
                self.plugin_manager.activatePluginByName(plugin_info.name)
                plugin_info.plugin_object.set_site(self)
                plugins.append(plugin_info)
        return plugins

    def render_template(self, name, _, context):
        return '<img src="IMG.jpg">'

    # this code duplicated in nikola/nikola.py
    def register_shortcode(self, name, f):
        """Register function f to handle shortcode "name"."""
        if name in self.shortcode_registry:
            nikola.utils.LOGGER.warning('Shortcode name conflict: %s', name)
            return
        self.shortcode_registry[name] = f

    def apply_shortcodes(self, data, *a, **kw):
        """Apply shortcodes from the registry on data."""
        return nikola.shortcodes.apply_shortcodes(data, self.shortcode_registry, **kw)

    def apply_shortcodes_uuid(self, data, shortcodes, *a, **kw):
        """Apply shortcodes from the registry on data."""
        return nikola.shortcodes.apply_shortcodes(data, self.shortcode_registry, **kw)


class FakePost:
    def __init__(self, title, slug):
        self._title = title
        self._slug = slug
        self._meta = {"slug": slug}

    def title(self):
        return self._title

    def meta(self, key):
        return self._meta[key]

    def permalink(self):
        return "/posts/" + self._slug



import os
from tempfile import NamedTemporaryFile

import pytest
from PIL import Image, ImageDraw

from nikola.plugins.task import scale_images

# These tests don't require valid profiles. They need only to verify
# that profile data is/isn't saved with images.
# It would be nice to use PIL.ImageCms to create valid profiles, but
# in many Pillow distributions ImageCms is a stub.
# ICC file data format specification:
# http://www.color.org/icc32.pdf
PROFILE = b"invalid profile data"


def test_handling_icc_profiles(test_images, destination_dir):
    filename, expected_profile = test_images

    pathname = os.path.join(str(destination_dir), filename)
    assert os.path.exists(pathname), pathname

    img = Image.open(pathname)
    actual_profile = img.info.get("icc_profile")
    assert actual_profile == expected_profile


@pytest.fixture(
    params=[
        pytest.param(True, id="with icc filename"),
        pytest.param(False, id="without icc filename"),
    ]
)
def test_images(request, preserve_icc_profiles, source_dir, site):
    image_filename = create_src_image(str(source_dir), request.param)
    run_task(site)

    if request.param:
        yield image_filename, PROFILE if preserve_icc_profiles else None
    else:
        yield image_filename, None


@pytest.fixture(
    params=[
        pytest.param(True, id="profiles preserved"),
        pytest.param(False, id="profiles not preserved"),
    ]
)
def preserve_icc_profiles(request):
    return request.param


@pytest.fixture
def source_dir(tmpdir_factory):
    return tmpdir_factory.mktemp("image_source")


@pytest.fixture
def site(preserve_icc_profiles, source_dir, destination_dir):
    config = {
        "IMAGE_FOLDERS": {str(source_dir): ""},
        "OUTPUT_FOLDER": str(destination_dir),
        "IMAGE_THUMBNAIL_SIZE": 128,
        "IMAGE_THUMBNAIL_FORMAT": "{name}.thumbnail{ext}",
        "MAX_IMAGE_SIZE": 512,
        "FILTERS": {},
        "PRESERVE_EXIF_DATA": False,
        "EXIF_WHITELIST": {},
        "PRESERVE_ICC_PROFILES": preserve_icc_profiles,
    }
    return FakeSite(config)


class FakeSite:
    def __init__(self, config):
        self.config = config
        self.debug = True


@pytest.fixture
def destination_dir(tmpdir_factory):
    return tmpdir_factory.mktemp("image_output")


def run_task(site):
    task_instance = get_task_instance(site)
    for task in task_instance.gen_tasks():
        for action, args in task.get("actions", []):
            action(*args)


def get_task_instance(site):
    result = scale_images.ScaleImage()
    result.set_site(site)
    return result


def create_src_image(testdir, use_icc_profile):
    img = create_test_image()
    pathname = tmp_img_name(testdir)

    # Test two variants: with and without an associated icc_profile
    if use_icc_profile:
        img.save(pathname, icc_profile=PROFILE)
    else:
        img.save(pathname)

    return os.path.basename(pathname)


def create_test_image():
    # Make a white image with a red stripe on the diagonal.
    width = 64
    height = 64
    img = Image.new("RGB", (width, height), (255, 255, 255))
    draw = ImageDraw.Draw(img)
    draw.line((0, 0, width, height), fill=(255, 128, 128))
    draw.line((width, 0, 0, height), fill=(128, 128, 255))
    return img


def tmp_img_name(dirname):
    pathname = NamedTemporaryFile(suffix=".jpg", dir=dirname, delete=False)
    return pathname.name



"""Test if PAGE_INDEX works, with different PRETTY_URLS=True."""

import os

import pytest

import nikola.plugins.command.init
from nikola import __main__

from .helper import append_config, cd
from .test_empty_build import (  # NOQA
    test_archive_exists,
    test_avoid_double_slash_in_rss,
    test_check_files,
    test_check_links,
    test_index_in_sitemap,
)
from .test_page_index_normal_urls import create_pages
from .test_page_index_normal_urls import (  # NOQA
    test_page_index,
    test_page_index_in_subdir,
    test_page_index_content_in_pages,
    test_page_index_content_in_subdir1,
    test_page_index_content_in_subdir2,
    test_page_index_content_in_subdir3,
)


@pytest.fixture(scope="module")
def output_path_func():
    def output_path(dir, name):
        """Make a file path to the output."""
        return os.path.join(dir, name + "/index.html")

    return output_path


@pytest.fixture(scope="module")
def build(target_dir):
    """Build the site."""
    init_command = nikola.plugins.command.init.CommandInit()
    init_command.create_empty_site(target_dir)
    init_command.create_configuration(target_dir)

    create_pages(target_dir)

    append_config(
        target_dir,
        """
PAGE_INDEX = True
PRETTY_URLS = True
PAGES = PAGES + (('pages/*.php', 'pages', 'page.tmpl'),)
""",
    )

    with cd(target_dir):
        __main__.main(["build"])



"""
Simple plugin tests.

More advanced tests should be in a separate module.
"""


def test_command_version():
    """Test `nikola version`."""
    from nikola.plugins.command.version import CommandVersion

    CommandVersion().execute()


def test_importing_plugin_task_galleries():
    import nikola.plugins.task.galleries  # NOQA


def test_importing_plugin_compile_pandoc():
    import nikola.plugins.compile.pandoc  # NOQA



"""Test that CATEGORIES_INDEX_PATH and TAGS_INDEX_PATH return the correct values on Unix and Windows."""
from unittest import mock

from nikola import Nikola
from nikola.plugins.misc.taxonomies_classifier import TaxonomiesClassifier
from nikola.plugins.task.authors import ClassifyAuthors
from nikola.plugins.task.categories import ClassifyCategories
from nikola.plugins.task.tags import ClassifyTags
from nikola.plugins.task.taxonomies import RenderTaxonomies

import pytest


@pytest.fixture(params=[ClassifyAuthors, ClassifyCategories, ClassifyTags], ids=["authors", "categories", "tags"])
def taxonomy(request):
    return request.param()


@pytest.fixture(params=[
    "base:", "base:blog", "base:path/with/trailing/slash/", "base:/path/with/leading/slash",
    "index:tags.html", "index:blog/tags.html", "index:path/to/tags.html", "index:/path/with/leading/slash.html",
])
def path(request):
    return request.param


@pytest.fixture
def fixture(taxonomy, path):
    scheme, _, path = path.partition(':')
    append_index = scheme == 'base'
    if isinstance(taxonomy, ClassifyAuthors) and append_index:
        site = Nikola(TRANSLATIONS={"en": ""}, AUTHOR_PATH=path)
    elif isinstance(taxonomy, ClassifyAuthors) and not append_index:
        pytest.skip("There is no AUTHORS_INDEX_PATH setting")
    elif isinstance(taxonomy, ClassifyCategories) and append_index:
        site = Nikola(TRANSLATIONS={"en": ""}, CATEGORY_PATH=path)
    elif isinstance(taxonomy, ClassifyCategories) and not append_index:
        site = Nikola(TRANSLATIONS={"en": ""}, CATEGORIES_INDEX_PATH=path)
    elif isinstance(taxonomy, ClassifyTags) and append_index:
        site = Nikola(TRANSLATIONS={"en": ""}, TAG_PATH=path)
    elif isinstance(taxonomy, ClassifyTags) and not append_index:
        site = Nikola(TRANSLATIONS={"en": ""}, TAGS_INDEX_PATH=path)
    else:
        raise TypeError("Unknown taxonomy %r" % type(taxonomy))

    site._template_system = mock.MagicMock()
    site._template_system.template_deps.return_value = []
    site._template_system.name = "dummy"
    site.hierarchy_per_classification = {taxonomy.classification_name: {"en": []}}
    site.posts_per_classification = {taxonomy.classification_name: {"en": {}}}
    site.taxonomy_plugins = {taxonomy.classification_name: taxonomy}

    taxonomy.set_site(site)

    classifier = TaxonomiesClassifier()
    classifier.set_site(site)

    expected = path.strip("/")
    if append_index:
        expected += "/"
    if not expected.startswith("/"):
        expected = "/" + expected

    return site, classifier, taxonomy, append_index, expected


def test_render_taxonomies_permalink(fixture):
    # Arrange
    site, _, taxonomy, _, expected = fixture
    renderer = RenderTaxonomies()
    renderer.set_site(site)

    # Act
    tasks = list(renderer._generate_classification_overview(taxonomy, "en"))

    # Assert
    action, args = tasks[0]["actions"][0]
    context = args[2]
    assert context["permalink"] == expected


def test_taxonomy_index_path_helper(fixture):
    # Arrange
    site, _, taxonomy, _, expected = fixture

    # Act
    path = site.path(taxonomy.classification_name + "_index", "name", "en", is_link=True)

    # Assert
    assert path == expected


def test_taxonomy_classifier_index_path(fixture):
    # Arrange
    site, classifier, taxonomy, append_index, expected = fixture
    if append_index:
        expected += "index.html"

    # Act
    path = classifier._taxonomy_index_path("name", "en", taxonomy)

    # Assert
    assert path == [x for x in expected.split('/') if x]


def test_taxonomy_overview_path(fixture):
    # Arrange
    _, _, taxonomy, append_index, expected = fixture

    # Act
    result = taxonomy.get_overview_path("en")

    # Assert
    assert result == ([x for x in expected.split('/') if x], "always" if append_index else "never")



import io
import os
import shutil

from ..helper import cd

__all__ = ["add_post_without_text", "append_config", "cd", "create_simple_post", "patch_config"]


def add_post_without_text(directory):
    """Add a post without text."""
    # File for Issue #374 (empty post text)
    create_simple_post(directory, "empty.txt", "foobar")


def create_simple_post(directory, filename, title_slug, text='', date='2013-03-06 19:08:15'):
    """Create a simple post in a given directory."""
    path = os.path.join(directory, filename)
    text_processed = '\n' + text if text else ''
    with io.open(path, "w+", encoding="utf8") as outf:
        outf.write(
            """
.. title: {0}
.. slug: {0}
.. date: {1}
{2}""".format(title_slug, date, text_processed)
        )


def copy_example_post(destination_dir):
    """Copy a modified version of the example post into the site."""
    test_dir = os.path.abspath(os.path.dirname(__file__))
    source_file = os.path.join(test_dir, "..", "data", "1-nolinks.rst")
    destination = os.path.join(destination_dir, "1.rst")
    shutil.copy(source_file, destination)


def append_config(config_dir, appendix):
    """Append text to the config file."""
    config_path = os.path.join(config_dir, "conf.py")
    with io.open(config_path, "a", encoding="utf8") as outf:
        outf.write(appendix)


def patch_config(config_dir, *replacements):
    """Patch the config file with new values (find and replace)."""
    config_path = os.path.join(config_dir, "conf.py")
    with io.open(config_path, "r", encoding="utf-8") as inf:
        data = inf.read()

    for old, new in replacements:
        data = data.replace(old, new)

    with io.open(config_path, "w+", encoding="utf8") as outf:
        outf.write(data)
        outf.flush()



"""Check that full archives build and are correct."""

import os

import pytest

from nikola import __main__

from .helper import cd, patch_config
from .test_demo_build import prepare_demo_site
from .test_empty_build import (  # NOQA
    test_avoid_double_slash_in_rss,
    test_check_files,
    test_check_links,
    test_index_in_sitemap,
)


@pytest.mark.parametrize(
    "path",
    [
        pytest.param(["archive.html"], id="overall"),
        pytest.param(["2012", "index.html"], id="year"),
        pytest.param(["2012", "03", "index.html"], id="month"),
        pytest.param(["2012", "03", "30", "index.html"], id="day"),
    ],
)
def test_full_archive(build, output_dir, path):
    """Check existance of archive pages"""
    expected_path = os.path.join(output_dir, *path)
    assert os.path.isfile(expected_path)


@pytest.fixture(scope="module")
def build(target_dir):
    """Fill the site with demo content and build it."""
    prepare_demo_site(target_dir)

    patch_config(
        target_dir, ("# CREATE_FULL_ARCHIVES = False", "CREATE_FULL_ARCHIVES = True")
    )

    with cd(target_dir):
        __main__.main(["build"])



"""
Check REDIRECTIONS.

This module tests absolute, external and relative redirects.
Each of the different redirect types is specified in the config and
then tested by at least one test."""

import io
import os

import pytest

import nikola.plugins.command.init
from nikola import __main__

from .helper import append_config, cd
from .test_demo_build import prepare_demo_site
from .test_empty_build import (  # NOQA
    test_archive_exists,
    test_avoid_double_slash_in_rss,
    test_check_files,
    test_check_links,
    test_index_in_sitemap,
)


def test_absolute_redirection(build, output_dir):
    abs_source = os.path.join(output_dir, "redirects", "absolute_source.html")
    assert os.path.exists(abs_source)

    abs_destination = os.path.join(output_dir, "posts", "absolute.html")
    assert os.path.exists(abs_destination)

    with open(abs_destination) as abs_destination_fd:
        abs_destination_content = abs_destination_fd.read()

    redirect_tag = '<meta http-equiv="refresh" content="0; url=/redirects/absolute_source.html">'
    assert redirect_tag in abs_destination_content

    with open(abs_source) as abs_source_fd:
        absolute_source_content = abs_source_fd.read()

    assert absolute_source_content == "absolute"


def test_external_redirection(build, output_dir):
    ext_link = os.path.join(output_dir, "external.html")

    assert os.path.exists(ext_link)
    with open(ext_link) as ext_link_fd:
        ext_link_content = ext_link_fd.read()

    redirect_tag = '<meta http-equiv="refresh" content="0; url=http://www.example.com/">'
    assert redirect_tag in ext_link_content


def test_relative_redirection(build, output_dir):
    rel_destination = os.path.join(output_dir, "relative.html")
    assert os.path.exists(rel_destination)
    rel_source = os.path.join(output_dir, "redirects", "rel_src.html")
    assert os.path.exists(rel_source)

    with open(rel_destination) as rel_destination_fd:
        rel_destination_content = rel_destination_fd.read()

    redirect_tag = '<meta http-equiv="refresh" content="0; url=redirects/rel_src.html">'
    assert redirect_tag in rel_destination_content

    with open(rel_source) as rel_source_fd:
        rel_source_content = rel_source_fd.read()

    assert rel_source_content == "relative"


@pytest.fixture(scope="module")
def build(target_dir):
    """Fill the site with demo content and build it."""
    prepare_demo_site(target_dir)

    redirects_dir = os.path.join(target_dir, "files", "redirects")
    nikola.utils.makedirs(redirects_dir)

    # Source file for absolute redirect
    target_path = os.path.join(redirects_dir, "absolute_source.html")
    with io.open(target_path, "w+", encoding="utf8") as outf:
        outf.write("absolute")

    # Source file for relative redirect
    target_path = os.path.join(redirects_dir, "rel_src.html")
    with io.open(target_path, "w+", encoding="utf8") as outf:
        outf.write("relative")

    # Configure usage of specific redirects
    append_config(
        target_dir,
        """
REDIRECTIONS = [
    ("posts/absolute.html", "/redirects/absolute_source.html"),
    ("external.html", "http://www.example.com/"),
    ("relative.html", "redirects/rel_src.html"),
]
""",
    )

    with cd(target_dir):
        __main__.main(["build"])



# -*- encoding:utf-8 -*-
"""Autogenerated file, do not edit. Submit translations on Transifex."""

MESSAGES = {
    "%d min remaining to read": "%d minuta preostalo za čitanje",
    "(active)": "(aktivno)",
    "Also available in:": "Takođe dostupan u:",
    "Archive": "Arhiva",
    "Atom feed": "",
    "Authors": "",
    "Categories": "Kategorije",
    "Comments": "Komentari",
    "LANGUAGE": "Bosanski",
    "Languages:": "Jezici:",
    "More posts about %s": "Više objava o %s",
    "Newer posts": "Novije objave",
    "Next post": "Naredna objava",
    "Next": "",
    "No posts found.": "Nema objava.",
    "Nothing found.": "Ništa nije pronađeno.",
    "Older posts": "Starije objave",
    "Original site": "Izvorni sajt",
    "Posted:": "Objavljeno:",
    "Posts about %s": "Objave o %s",
    "Posts by %s": "",
    "Posts for year %s": "Objave u godini %s",
    "Posts for {month_day_year}": "Objave za {month_day_year}",
    "Posts for {month_year}": "Objave za {month_year}",
    "Previous post": "Prethodne objave",
    "Previous": "",
    "Publication date": "Datum objavljivanja",
    "RSS feed": "RSS feed",
    "Read in English": "Pročitaj na bosanskom",
    "Read more": "Pročitaj više",
    "Skip to main content": "Preskoči na glavni sadržaj",
    "Source": "Izvor",
    "Subcategories:": "Podkategorije:",
    "Tags and Categories": "Oznake i kategorije",
    "Tags": "Oznake",
    "Toggle navigation": "",
    "Uncategorized": "",
    "Up": "",
    "Updates": "",
    "Write your page here.": "Vašu stranicu napišite ovdje.",
    "Write your post here.": "Vašu objavu napišite ovdje.",
    "old posts, page %d": "stare objave, strana %d",
    "page %d": "strana %d",
    "updated": "",
}



"""
Test that a default build of a new site based on the demo site works.

This module also is one place where green path tests (working as
expected) for the `check` command are tested.
In this case these are tested against the demo site with default
settings.
"""

import os

import pytest

import nikola.plugins.command.init
from nikola import __main__

from .helper import add_post_without_text, cd, copy_example_post
from .test_empty_build import (  # NOQA
    test_archive_exists,
    test_avoid_double_slash_in_rss,
    test_check_files,
    test_check_links,
    test_index_in_sitemap,
)


@pytest.fixture(scope="module")
def build(target_dir):
    """Fill the site with demo content and build it."""
    prepare_demo_site(target_dir)

    with cd(target_dir):
        __main__.main(["build"])


def prepare_demo_site(target_dir):
    init_command = nikola.plugins.command.init.CommandInit()
    init_command.copy_sample_site(target_dir)
    init_command.create_configuration(target_dir)

    posts_dir = os.path.join(target_dir, "posts")
    copy_example_post(posts_dir)
    add_post_without_text(posts_dir)



"""Test a site with future posts."""

import io
import os
from datetime import timedelta

import pytest

import nikola
import nikola.plugins.command.init
from nikola.utils import current_time
from nikola import __main__

from .helper import append_config, cd
from .test_empty_build import (  # NOQA
    test_archive_exists,
    test_avoid_double_slash_in_rss,
    test_check_files,
    test_check_links,
    test_index_in_sitemap,
)


def test_future_post_deployment(build, output_dir, target_dir):
    """ Ensure that the future post is deleted upon deploying. """
    index_path = os.path.join(output_dir, "index.html")
    post_in_past = os.path.join(output_dir, "posts", "foo", "index.html")
    post_in_future = os.path.join(output_dir, "posts", "bar", "index.html")

    assert os.path.isfile(index_path)
    assert os.path.isfile(post_in_past)
    assert os.path.isfile(post_in_future)

    # Run deploy command to see if future post is deleted
    with cd(target_dir):
        __main__.main(["deploy"])

    assert os.path.isfile(index_path)
    assert os.path.isfile(post_in_past)
    assert not os.path.isfile(post_in_future)


@pytest.mark.parametrize("filename", ["index.html", "sitemap.xml"])
def test_future_post_not_in_indexes(build, output_dir, filename):
    """ Ensure that the future post is not present in the index and sitemap."""
    filepath = os.path.join(output_dir, filename)
    assert os.path.isfile(filepath)

    with io.open(filepath, "r", encoding="utf8") as inf:
        content = inf.read()
    assert "foo/" in content
    assert "bar/" not in content
    assert "baz" not in content


@pytest.fixture(scope="module")
def build(target_dir):
    """Build the site."""
    init_command = nikola.plugins.command.init.CommandInit()
    init_command.create_empty_site(target_dir)
    init_command.create_configuration(target_dir)

    # Change COMMENT_SYSTEM_ID to not wait for 5 seconds
    append_config(target_dir, '\nCOMMENT_SYSTEM_ID = "nikolatest"\n')

    def format_datetime(datetime):
        return datetime.strftime("%Y-%m-%d %H:%M:%S")

    past_datetime = format_datetime(current_time() + timedelta(days=-1))
    with io.open(
        os.path.join(target_dir, "posts", "empty1.txt"), "w+", encoding="utf8"
    ) as past_post:
        past_post.write(
            """\
.. title: foo
.. slug: foo
.. date: %s
"""
            % past_datetime
        )

    future_datetime = format_datetime(current_time() + timedelta(days=1))
    with io.open(
        os.path.join(target_dir, "posts", "empty2.txt"), "w+", encoding="utf8"
    ) as future_post:
        future_post.write(
            """\
.. title: bar
.. slug: bar
.. date: %s
"""
            % future_datetime
        )

    with io.open(
        os.path.join(target_dir, "posts", "empty3.txt"), "w+", encoding="utf8"
    ) as future_post:
        future_post.write(
            """\
.. title: baz
.. slug: baz
.. date: %s
.. pretty_url: false
"""
            % future_datetime
        )

    with cd(target_dir):
        __main__.main(["build"])



# -*- coding: utf-8 -*-
"""
Testing the wordpress import.

It will do create a new site with the import_wordpress command
and use that newly created site to make a build.
"""

import os.path
from glob import glob

import pytest

from nikola import __main__

from .helper import cd
from .test_empty_build import (  # NOQA
    test_archive_exists,
    test_avoid_double_slash_in_rss,
    test_check_files,
)


def test_import_created_files(build, target_dir):
    assert os.path.exists(target_dir)
    assert os.path.exists(os.path.join(target_dir, "conf.py"))


@pytest.mark.parametrize("dirname", ["pages", "posts"])
def test_filled_directories(build, target_dir, dirname):
    folder = os.path.join(target_dir, dirname)
    assert os.path.isdir(folder)
    content = glob(os.path.join(folder, "**"), recursive=True)
    assert any(os.path.isfile(element) for element in content)


@pytest.fixture(scope="module")
def build(target_dir, import_file):
    __main__.main(
        [
            "import_wordpress",
            "--no-downloads",
            "--output-folder",
            target_dir,
            import_file,
        ]
    )

    with cd(target_dir):
        result = __main__.main(["build"])
        assert not result


@pytest.fixture(scope="module")
def import_file(test_dir):
    """Path to the Wordpress export file."""
    return os.path.join(
        test_dir, "..", "data", "wordpress_import", "wordpress_export_example.xml"
    )



import io
from os import path

import pytest

from nikola.plugins.compile.markdown import CompileMarkdown

from .helper import FakeSite


@pytest.mark.parametrize(
    "input_str, expected_output",
    [
        pytest.param("", "", id="empty"),
        pytest.param(
            "[podcast]https://archive.org/download/Rebeldes_Stereotipos/rs20120609_1.mp3[/podcast]",
            '<p><audio controls=""><source src="https://archive.org/download/Rebeldes_Stereotipos/rs20120609_1.mp3" type="audio/mpeg"></source></audio></p>',
            id="mdx podcast",
        ),
        pytest.param(
            "~~striked out text~~",
            "<p><del>striked out text</del></p>",
            id="strikethrough",
        ),
        pytest.param(
            """\
    #!python
    from this
""",
            """\
<table class="codehilitetable"><tr><td class="linenos">\
<div class="linenodiv"><pre>1</pre></div>\
</td><td class="code"><pre class="code literal-block"><span></span>\
<code><span class="kn">from</span> <span class="nn">this</span>
</code></pre>
</td></tr></table>
""",
            id="hilite",
        ),
    ],
)
def test_compiling_markdown(
    compiler, input_path, output_path, input_str, expected_output
):
    output = markdown_compile(compiler, input_path, output_path, input_str)
    assert output.strip() == expected_output.strip()


@pytest.fixture(scope="module")
def site():
    return FakeSite()


@pytest.fixture(scope="module")
def compiler(site):
    compiler = CompileMarkdown()
    compiler.set_site(site)
    return compiler


@pytest.fixture
def input_path(tmpdir):
    return path.join(str(tmpdir), "input.markdown")


@pytest.fixture
def output_path(tmpdir):
    return path.join(str(tmpdir), "output.html")


def markdown_compile(compiler, input_path, output_path, text):
    with io.open(input_path, "w+", encoding="utf8") as input_file:
        input_file.write(text)

    compiler.compile(input_path, output_path, lang="en")

    with io.open(output_path, "r", encoding="utf8") as output_path:
        return output_path.read()



# -*- coding: utf-8 -*-

# Copyright © 2012-2021 Roberto Alsina and others.

# Permission is hereby granted, free of charge, to any
# person obtaining a copy of this software and associated
# documentation files (the "Software"), to deal in the
# Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the
# Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice
# shall be included in all copies or substantial portions of
# the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY
# KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
# WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
# PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS
# OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
# OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
# OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

"""SoundCloud directive for reStructuredText."""

from docutils import nodes
from docutils.parsers.rst import Directive, directives
from nikola.plugins.compile.rest import _align_choice, _align_options_base

from nikola.plugin_categories import RestExtension


class Plugin(RestExtension):
    """Plugin for soundclound directive."""

    name = "rest_soundcloud"

    def set_site(self, site):
        """Set Nikola site."""
        self.site = site
        directives.register_directive('soundcloud', SoundCloud)
        directives.register_directive('soundcloud_playlist', SoundCloudPlaylist)
        return super().set_site(site)


CODE = """\
<div class="soundcloud-player{align}">
<iframe width="{width}" height="{height}"
scrolling="no" frameborder="no"
src="https://w.soundcloud.com/player/?url=http://api.soundcloud.com/{preslug}/{sid}">
</iframe>
</div>"""


class SoundCloud(Directive):
    """reST extension for inserting SoundCloud embedded music.

    Usage:
        .. soundcloud:: <sound id>
           :height: 400
           :width: 600

    """

    has_content = True
    required_arguments = 1
    option_spec = {
        'width': directives.positive_int,
        'height': directives.positive_int,
        "align": _align_choice
    }
    preslug = "tracks"

    def run(self):
        """Run the soundcloud directive."""
        self.check_content()
        options = {
            'sid': self.arguments[0],
            'width': 600,
            'height': 160,
            'preslug': self.preslug,
        }
        options.update(self.options)
        if self.options.get('align') in _align_options_base:
            options['align'] = ' align-' + self.options['align']
        else:
            options['align'] = ''
        return [nodes.raw('', CODE.format(**options), format='html')]

    def check_content(self):
        """Emit a deprecation warning if there is content."""
        if self.content:  # pragma: no cover
            raise self.warning("This directive does not accept content. The "
                               "'key=value' format for options is deprecated, "
                               "use ':key: value' instead")


class SoundCloudPlaylist(SoundCloud):
    """reST directive for SoundCloud playlists."""

    preslug = "playlists"



"""Test slugify."""

import pytest

import nikola.utils


@pytest.mark.parametrize(
    "title, language, expected_slug",
    [
        pytest.param("hello", "en", "hello", id="ASCII"),
        pytest.param("hello-world", "en", "hello-world", id="ASCII with dashes"),
        pytest.param("hello world", "en", "hello-world", id="ASCII two words"),
        pytest.param("Hello World", "en", "hello-world", id="ASCII uppercase"),
        pytest.param(
            "The quick brown fox jumps over the lazy dog!-123.456",
            "en",
            "the-quick-brown-fox-jumps-over-the-lazy-dog-123456",
            id="ASCII with fancy characters",
        ),
        pytest.param(
            "zażółćgęśląjaźń",
            "pl",
            "zazolcgeslajazn",
            id="Polish diacritical characters",
        ),
        pytest.param(
            "zażółć-gęślą-jaźń",
            "pl",
            "zazolc-gesla-jazn",
            id="Polish diacritical characters and dashes",
        ),
        pytest.param(
            "Zażółć gęślą jaźń!-123.456",
            "pl",
            "zazolc-gesla-jazn-123456",
            id="Polish diacritical characters and fancy characters",
        ),
    ],
)
def test_slugify(title, language, expected_slug):
    o = nikola.utils.slugify(title, lang=language)
    assert o == expected_slug
    assert isinstance(o, str)


@pytest.mark.parametrize(
    "title, expected_slug",
    [
        pytest.param(
            u"Zażółć gęślą jaźń!-123.456", u"Zażółć gęślą jaźń!-123.456", id="polish"
        ),
        pytest.param(
            u'Zażółć gęślą jaźń!-123.456 "Hello World"?#H<e>l/l\\o:W\'o\rr*l\td|!\n',
            u"Zażółć gęślą jaźń!-123.456 -Hello World---H-e-l-l-o-W-o-r-l-d-!-",
            id="polish with banned characters",
        ),
    ],
)
def test_disarmed(disarm_slugify, title, expected_slug):
    """Test disarmed slugify."""
    o = nikola.utils.slugify(title, lang="pl")
    assert o == expected_slug
    assert isinstance(o, str)


@pytest.fixture
def disarm_slugify():
    nikola.utils.USE_SLUGIFY = False
    try:
        yield
    finally:
        nikola.utils.USE_SLUGIFY = True



"""
Various integration tests for the Nikola commands.

Each test module provides a different build fixture that will create a
build in the desired way that then later can be checked in test
functions.
To avoid duplicating code many of the fixtures are shared between
modules.

The build fixtures are scoped for module level in order to avoid
re-building the whole site for every test and to make these tests fast.
"""
